@@ -6,13 +6,13 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0000_03'; # TRIAL VERSION
 
 use PDL::Core qw(ones);
 use PDL::Lite;
 use Math::LOESS::_swig;
 use Type::Params qw(compile compile_named);
-use Types::Standard qw(Any Num Object Optional);
+use Types::Standard qw(Any Num Object Optional Str);
 use Types::PDL qw(Piddle1D);
 
 use Math::LOESS::Model;
@@ -26,17 +26,20 @@ sub new {
         y       => Piddle1D,
         weights => Optional [Piddle1D],
         span    => Optional [ Num->where( sub { $_ > 0 and $_ < 1 } ) ],
-                   { default => 0.75 },
+        family  => Optional [ Str ],
     );
 
     my $arg = $check->(@_);
 
-    my ( $x, $y, $span ) = map { $arg->{$_} } qw(x y span);
+    my ( $x, $y, $span, $family ) = map { $arg->{$_} } qw(x y span family);
     my $n = $y->dim(0);
     my $p = $x->dim(0) / $y->dim(0);
     unless ( int($p) == $p ) {
         die "x's length must be same as, or integral times as, that of y";
     }
+    if ($p > 8) {
+        die "Cannot have more than 8 ($p seen) predictors.";
+    }
 
     my $w = $arg->{weights};
     if ( defined $w ) {
@@ -74,18 +77,21 @@ sub new {
       ( $x1, $y1, defined $w1 ? $w1 : () );
 
     $self->{model} = Math::LOESS::Model->new( _obj => $self->_obj->{model} );
+    if ( defined $span ) {
+        $self->model->span($span);
+    }
+    if ( defined $family ) {
+        $self->model->family($family);
+    }
+
     $self->{outputs} = Math::LOESS::Outputs->new(
         _obj   => $self->_obj->{outputs},
         _loess => $self,
-        n      => $self->_inputs_n,
-        p      => $self->_inputs_p,
+        n      => $self->n,
+        p      => $self->p,
         family => $self->model->family,
     );
 
-    if (defined $span) {
-        $self->model->span($span);
-    }
-
     return $self;
 }
 
@@ -100,14 +106,14 @@ for my $attr (qw(_obj activated model outputs)) {
 }
 
 sub _inputs   { $_[0]->_obj->{inputs} }
-sub _inputs_n { $_[0]->_inputs->{n} }
-sub _inputs_p { $_[0]->_inputs->{p} }
+sub n { $_[0]->_inputs->{n} }
+sub p { $_[0]->_inputs->{p} }
 
 sub _size {
     my ( $self, $attr ) = @_;
     return $attr eq 'x'
-      ? $self->_inputs_n * $self->_inputs_p
-      : $self->_inputs_n;
+      ? $self->n * $self->p
+      : $self->n;
 }
 
 for my $attr (qw(x y weights)) {
@@ -147,7 +153,11 @@ sub predict {
     }
 
     my $pred = Math::LOESS::_swig::prediction->new();
-    $pred->{m} = $newdata->dim(0);
+    my $m = $newdata->dim(0) / $self->p;
+    unless ( int($m) == $m ) {
+        die "newdata's length must be integral times as that of the p value";
+    }
+    $pred->{m} = $m;
     $pred->{se} = $stderr ? 1 : 0; 
 
     my $d = Math::LOESS::_swig::pdl_to_darray($newdata);
@@ -169,7 +179,7 @@ Number of Observations         : %d
 Fit flag                       : %d
 Equivalent Number of Parameters: %.1f
 EOT
-        $self->_inputs->{n}, $fit_flag, $self->outputs->enp
+        $self->n, $fit_flag, $self->outputs->enp
     );
 
     if ($fit_flag) {
@@ -196,7 +206,7 @@ Math::LOESS - Perl wrapper of the Locally-Weighted Regression package originally
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0000_03
 
 =head1 SYNOPSIS
 
@@ -218,7 +228,7 @@ version 0.0000_02
 =head1 CONSTRUCTION
 
     new(Piddle1D :$x, Piddle1D :$y, Piddle1D :$weights=undef,
-        Num :$span=0.75)
+        Num :$span=0.75, Str :$family='gaussian')
 
 Arguments:
 
@@ -226,7 +236,10 @@ Arguments:
 
 =item * $x
 
-A L<PDL> piddle for x data. 
+A L<PDL> piddle for x data.
+
+In case of multiple predictors, C<$x> is a glued piddle containing all
+predictors' data. It's possible to have at most 8 predictors.
 
 =item * $y
 
@@ -238,19 +251,20 @@ Optional weights.
 
 =item * $span
 
-The parameter controls the degree of smoothing. Default is 0.75.
+I<POD INCLUDE ERROR: Can't load template 'span' from 'Math::LOESS::Model'.>
 
-For C<span> < 1, the neighbourhood used for the fit includes proportion
-C<span> of the points, and these have tricubic weighting (proportional to
-C<(1 - (dist/maxdist)^3)^3)>. For C<span> > 1, all points are used, with
-the "maximum distance" assumed to be C<span^(1/p)> times the actual
-maximum distance for p explanatory variables.
+When provided as a construction parameter, it is like a shortcut for,
 
-When provided as a construction parameter, it is like a shortcut of,
-
-    my $loess = Math::LOESS->new(...); 
     $loess->model->span($span);
 
+=item * $family
+
+I<POD INCLUDE ERROR: Can't load template 'family' from 'Math::LOESS::Model'.>
+
+When provided as a construction parameter, it is like a shortcut for,
+
+    $loess->model->family($family);
+
 =back
 
 =head1 NAME
@@ -293,7 +307,7 @@ Returns a true value if the object's C<fit()> method has been called.
 
     predict(Piddle1D $newdata, Bool $stderr=false)
 
-Returns a L<Math:LOESS::Prediction> object.
+Returns a L<Math::LOESS::Prediction> object.
 
 =head2 summary
 
