@@ -10,7 +10,7 @@ our $VERSION = '0.0000_02'; # TRIAL VERSION
 
 use Math::LOESS::_swig;
 use Type::Params qw(compile_named);
-use Types::Standard qw(Enum Object);
+use Types::Standard qw(ArrayRef Enum Object);
 
 sub new {
     my $class = shift;
@@ -45,17 +45,17 @@ sub family {
     return $self->_obj->{family};
 }
 
-#for my $attr (qw(parametric drop_square)) {
-#    no strict 'refs';
-#    *{$attr} = sub {
-#        my ($self, $value) = @_;
-#
-#        if (defined $value) {
-#            $self->_obj->{$attr} = $value;
-#        }
-#        return $self->_obj->{$attr};
-#    };
-#}
+for my $attr (qw(parametric drop_square)) {
+    no strict 'refs';
+    *{$attr} = sub {
+        my ($self, $value) = @_;
+
+        if (defined $value) {
+            $self->_obj->{$attr} = $value;
+        }
+        return $self->_obj->{$attr};
+    };
+}
 
 1;
 
@@ -71,13 +71,21 @@ Math::LOESS::Model - Math::LOESS model configurations
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0000_03
 
 =head1 DESCRIPTION
 
 You normally don't need to construct object of this class yourself.
 Instead you get the object from an L<Math::LOESS> object.
 
+=head1 NAME
+
+Math::LOESS::Model - Math::LOESS model configurations
+
+=head1 VERSION
+
+version 0.0000_02
+
 =head1 ATTRIBUTES
 
 =head2 span
@@ -133,4 +141,15 @@ This software is copyright (c) 2019 by Stephan Loyd.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHOR
+
+Stephan Loyd <sloyd@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2019 by Stephan Loyd.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
